Example uses of Thermo
======================

The following Jupyter notebooks show some of the many calculations that can be done with Thermo.

These problems often make use of `fluids <https://github.com/CalebBell/fluids>`_,  `ht <https://github.com/CalebBell/ht>`_,  `chemicals <https://github.com/CalebBell/chemicals>`_, and `pint <https://github.com/hgrecco/pint/>`_ so make sure you have them installed!
More details on the unit handling library can be found at :doc:`fluids.units <fluids.units>`.


.. toctree::
    :maxdepth: 1

    Examples/Working with Heat Transfer Fluids - Therminol LT.ipynb
    Examples/Validating Flash Calculations.ipynb
    Examples/High Molecular Weight Petroleum Pseudocomponents.ipynb
    Examples/Performing Large Numbers of Calculations with Thermo in Parallel.ipynb

    Examples/Chemical Thermodynamics for Process Simulation/Example 14.2 Joule-Thomson Effect.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Example 14.3 Adiabatic Compression and Expansion.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.02 Work and Temperature Change Upon Isentropic Compression of Oxygen.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.03 Reversible and Isothermal Compression of Liquid Water.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.04 Heat Effect Upon Mixing of Methane and Dodecane at Elevated Temperature and Pressure Using SRK.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.05 Required Power for R134a Compression Using a High Precision Equation of State.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.06 Required Volume for a Gas Storage Tank for Ammonia.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.07 Liquid Nitrogen Production Via Volume Expansion of the Compressed Gas.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.08 Required Compressor Power for Isothermal and Adiabatic Compression of a Gas Mixture (CO2, O2) Using the Ideal Gas Law.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.09 Temperature Change Upon Ethylene Expansion in Throttle Valves Using a High Precision EOS.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.10 Leakage Rate Change in Vacuum Distillation When Lowering the Column Pressure.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.11 Pressure Rise In a Storage Tank Upon Heating.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.12 Work and Temperature Change Upon Adiabatic Compression of Oxygen.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.13 Thermodynamic Cycle Calculation Using a High-Precision EOS.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.14 Refrigeration Cycle Calculation Using the Peng-Robinson EOS.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.15 Joule-Thomson Coefficient for Methane Using the Peng-Robinson EOS.ipynb
    Examples/Chemical Thermodynamics for Process Simulation/Problem 14.16 Compressor Duty and State Properties after Ammonia Compression.ipynb